@@ -125,6 +125,8 @@ macro_rules! uint_impl_common {
 
         impl crate::traits::integers::Integer for $name {
             type IntegerType = $_type;
+            type UnsignedGadget = $name;
+            type UnsignedIntegerType = $_type;
 
             const SIZE: usize = $size;
 
